@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 8                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2020 The PHP Group                                |
+   | Copyright (c) 1997-2023 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -601,8 +601,7 @@ PHP_METHOD(EventBufferEvent, connect)
 		s_un->sun_family = AF_UNIX;
 		ss_len          = sizeof(struct sockaddr_un);
 
-		strcpy(s_un->sun_path, addr + sizeof(PHP_EVENT_SUN_PREFIX) - 1);
-
+		strlcpy(s_un->sun_path, addr + sizeof(PHP_EVENT_SUN_PREFIX) - 1, sizeof(s_un->sun_path));
 	} else
 #endif
 		if (evutil_parse_sockaddr_port(addr, (struct sockaddr *) &ss, &ss_len)) {
